@@ -24,6 +24,7 @@ def add_images_to_existing_project(session, projnumber):
             resource = a["resource"]
             if isinstance(resource, session.types['User']):
                 user = resource
+
                 project_team.append(user)
 
     if existing_project is None:
@@ -48,6 +49,8 @@ def add_images_to_existing_project(session, projnumber):
                 image_template = template
             if template["name"] == "MovingImage_Template":
                 moving_image_template = template
+            if template["name"] == "Timetracking_Template":
+                timetrack_template = template
 
         interior_shots = [i for i in existing_project['children'] if "INT" in i["name"]]
         num_exist_int = 0
@@ -67,6 +70,7 @@ def add_images_to_existing_project(session, projnumber):
                 print(f"Number of addtional INT:{additional_ints}")
                 break
 
+        int_artist, ext_artist, moving_artist = None, None, None
         if additional_ints > 0:
             if len(project_team) > 1:
                 int_artist = select_artist(project_team, users, "Select INT artist")
@@ -220,6 +224,25 @@ def add_images_to_existing_project(session, projnumber):
                                "type": "assignment"}
                                )
 
+        for artist in [int_artist, ext_artist, moving_artist]:
+            for task_type in [t["task_type"] for t in timetrack_template["items"]]:
+                task = session.create(
+                    "Task",
+                    {
+                        "name": f"TT_{artist['first_name']}",
+                        "type": task_type,
+                        "parent": existing_project,
+                    },
+                )
+                session.create(
+                    "Appointment",
+                    {
+                        "context": task,
+                        "resource": artist,
+                        "type": "assignment",
+                    },
+                )
+
         if num_int == 0:
             desc = f"{num_ext} EXT"
         elif num_ext == 0:
