@@ -41,7 +41,7 @@ def get_ftrack_session():
 
 def select_artist(team, users, question):
     ia = pick([u["username"] for u in team if u["username"] not in [
-              "Hanne", "Nele", "Annelies"]], question, indicator="👉")
+              "Hanne", "Nele", "Annelies", "Pieter"]], question, indicator="👉")
     return [i for i in users if ia[0].lower() in i["username"].lower()][0]
 
 
